@@ -96,13 +96,17 @@ class BeakerProvider(Provider):
                 )
         return
 
+    async def prepare_provisioning(self, reqs):
+        """Prepare provisioning."""
+        pass
+
     async def can_provision(self, hosts):
         """Check that hosts can be provisioned."""
         return True
 
     def _allow_ssh_key(self, ssh_key):
 
-        with open(ssh_key, "r") as key_file:
+        with open(os.path.expanduser(ssh_key), "r") as key_file:
             key_content = key_file.read()
 
         return [
