@@ -20,6 +20,7 @@ import contextlib
 import datetime
 import json
 import logging
+import os
 import sys
 
 import yaml
@@ -79,14 +80,14 @@ def json_convertor(obj):
 
 def load_json(path):
     """Load JSON file into Python object."""
-    with open(path, "r") as file_data:
+    with open(os.path.expanduser(path), "r") as file_data:
         data = json.load(file_data)
     return data
 
 
 def load_yaml(path):
     """Load YAML file into Python object."""
-    with open(path, "r") as file_data:
+    with open(os.path.expanduser(path), "r") as file_data:
         data = yaml.safe_load(file_data)
     return data
 
@@ -94,7 +95,7 @@ def load_yaml(path):
 def save_to_json(path, data):
     """Serialize object into JSON file."""
     try:
-        with open(path, "w") as output:
+        with open(os.path.expanduser(path), "w") as output:
             json.dump(data, output, default=json_convertor, indent=2, sort_keys=True)
     except IOError as exc:
         logger.exception(exc)
@@ -105,7 +106,7 @@ def save_to_json(path, data):
 def fd_open(filename=None):
     """Use file or stout as output file descriptor."""
     if filename:
-        fd = open(filename, "w")
+        fd = open(os.path.expanduser(filename), "w")
     else:
         fd = sys.stdout
 
